@@ -1,6 +1,7 @@
 package WWW::JSON::Role::Authentication::OAuth1;
 use Moo::Role;
 use Net::OAuth;
+use URI;
 $Net::OAuth::PROTOCOL_VERSION = Net::OAuth::PROTOCOL_VERSION_1_0A;
 requires 'authentication';
 requires 'ua';
@@ -14,16 +15,18 @@ sub _validate_OAuth1 {
 }
 
 sub _auth_OAuth1 {
-    my ( $self, $auth, $req, $method, $uri, $params ) = @_;
-
+    my ( $self, $auth, $req) = @_;
+    my $q = URI->new;
+    # FIXME if we're sending a JSON payload we need to decode instead of this
+    $q->query($req->content);
     my $request = Net::OAuth->request("protected resource")->new(
         %$auth,
-        request_url      => $uri->as_string,
-        request_method   => $method,
+        request_url      => $req->uri,
+        request_method   => $req->method,
         signature_method => 'HMAC-SHA1',
         timestamp        => time(),
         nonce            => _nonce(),
-        extra_params     => $params,
+        extra_params     => {$q->query_form},
     );
     $request->sign;
     $request->to_authorization_header;
